=====
Tools
=====

Additional functionality.

.. automethod:: aiosend.CryptoPay.exchange

Usage example

.. literalinclude:: ../../examples/exchange.py

.. automethod:: aiosend.CryptoPay.get_balance_by_asset

Usage example

.. literalinclude:: ../../examples/get_balance_by_asset.py

.. automethod:: aiosend.CryptoPay.get_invoice

Usage example

.. literalinclude:: ../../examples/get_invoice.py

.. automethod:: aiosend.CryptoPay.get_check
.. automethod:: aiosend.CryptoPay.delete_all_checks
.. automethod:: aiosend.CryptoPay.delete_all_invoices
.. automethod:: aiosend.CryptoPay.get_rates_image